## Laboratory work №2
#### Download from pip use command:
```
pip install symphony-of-tranquility-php-formatter
```
#### To start program use command:
```
PhpCCF
```
#### Parameters to the command and description
```
-h, --help                  : help menu
-v, --verify -(p|d|f) /..   : verify your files(as output php_verification.log file);
                              /.. - path to project, directory or file.
-f, --format -(p|d|f) /..   : format your files(as output php_fixing.log file);
                               /.. - path to project directory or file
```
###### Created by Mysechko Artemii IPS-41